@@ -47,22 +47,19 @@ class OssFileCache():
         if file_path:
             if isinstance(file_path, str) and re.match("http", file_path) and file_path is not None:
                 bbcloud_python_sdk.download_file(url=file_path, save_path=local_path)
-                self.bucket.put_object_from_file(cache_path, local_path)
-
             elif isinstance(file_path, dict) or isinstance(file_path, list):
                 bbcloud_python_sdk.create_json_file(dst_path=local_path, dist=file_path)
-                self.bucket.put_object_from_file(cache_path, local_path)
-
             elif os.path.isdir(file_path):
                 bbcloud_python_sdk.zip_dirs(zip_filename=local_path, file_dir=file_path)
-                self.bucket.put_object_from_file(cache_path, local_path)
-
             elif os.path.isfile(file_path):
-                self.bucket.put_object_from_file(cache_path, file_path)
+                local_path = file_path
 
-        if del_local:
-            if os.path.exists(local_path):
-                os.remove(local_path)
+            self.bucket.put_object_from_file(cache_path, local_path)
+
+            if del_local:
+                if os.path.exists(local_path):
+                    os.remove(local_path)
+            return True
 
     def get(self, key, local_file):
         """
@@ -89,13 +86,13 @@ class OssFileCache():
 
         try:
             self.bucket.delete_object(cache_path)
+            return True
         except oss2.exceptions.NoSuchKey:
             return False
 
     def list_cache_objects(self):
         """
         获取文件夹OSS缓存文件
-        @param key:
         """
         prefix_path = "%s/%s" % (self.cache_path_root, self.namespace)
         list_dir = []
